==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/RedisquotaSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface RedisquotaSpecFluent<A extends RedisquotaSpecFluent<A>> extends Fluent<A>{


    public Long getConnectionPoolSize();
    public A withConnectionPoolSize(Long connectionPoolSize);
    public Boolean hasConnectionPoolSize();
    public A withNewConnectionPoolSize(String arg1);
    public A withNewConnectionPoolSize(long arg1);
    public A addToQuotas(int index,me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public A setToQuotas(int index,me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public A addToQuotas(me.snowdrop.istio.mixer.adapter.redisquota.Quota... items);
    public A addAllToQuotas(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Quota> items);
    public A removeFromQuotas(me.snowdrop.istio.mixer.adapter.redisquota.Quota... items);
    public A removeAllFromQuotas(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Quota> items);
    
/**
 * This method has been deprecated, please use method buildQuotas instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.redisquota.Quota> getQuotas();
    public List<me.snowdrop.istio.mixer.adapter.redisquota.Quota> buildQuotas();
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildQuota(int index);
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildFirstQuota();
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildLastQuota();
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildMatchingQuota(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.QuotaBuilder> predicate);
    public A withQuotas(List<me.snowdrop.istio.mixer.adapter.redisquota.Quota> quotas);
    public A withQuotas(me.snowdrop.istio.mixer.adapter.redisquota.Quota... quotas);
    public Boolean hasQuotas();
    public RedisquotaSpecFluent.QuotasNested<A> addNewQuota();
    public RedisquotaSpecFluent.QuotasNested<A> addNewQuotaLike(me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public RedisquotaSpecFluent.QuotasNested<A> setNewQuotaLike(int index,me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public RedisquotaSpecFluent.QuotasNested<A> editQuota(int index);
    public RedisquotaSpecFluent.QuotasNested<A> editFirstQuota();
    public RedisquotaSpecFluent.QuotasNested<A> editLastQuota();
    public RedisquotaSpecFluent.QuotasNested<A> editMatchingQuota(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.QuotaBuilder> predicate);
    public String getRedisServerUrl();
    public A withRedisServerUrl(String redisServerUrl);
    public Boolean hasRedisServerUrl();

    public interface QuotasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.redisquota.QuotaFluent<RedisquotaSpecFluent.QuotasNested<N>>{

        
    public N and();    public N endQuota();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/RedisquotaSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface RedisquotaSpecFluent<A extends RedisquotaSpecFluent<A>> extends Fluent<A>{


    public Integer getConnectionPoolSize();
    public A withConnectionPoolSize(Integer connectionPoolSize);
    public Boolean hasConnectionPoolSize();
    public A addToQuotas(int index,me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public A setToQuotas(int index,me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public A addToQuotas(me.snowdrop.istio.mixer.adapter.redisquota.Quota... items);
    public A addAllToQuotas(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Quota> items);
    public A removeFromQuotas(me.snowdrop.istio.mixer.adapter.redisquota.Quota... items);
    public A removeAllFromQuotas(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Quota> items);
    public A removeMatchingFromQuotas(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.QuotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildQuotas instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.redisquota.Quota> getQuotas();
    public List<me.snowdrop.istio.mixer.adapter.redisquota.Quota> buildQuotas();
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildQuota(int index);
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildFirstQuota();
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildLastQuota();
    public me.snowdrop.istio.mixer.adapter.redisquota.Quota buildMatchingQuota(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.QuotaBuilder> predicate);
    public Boolean hasMatchingQuota(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.QuotaBuilder> predicate);
    public A withQuotas(List<me.snowdrop.istio.mixer.adapter.redisquota.Quota> quotas);
    public A withQuotas(me.snowdrop.istio.mixer.adapter.redisquota.Quota... quotas);
    public Boolean hasQuotas();
    public RedisquotaSpecFluent.QuotasNested<A> addNewQuota();
    public RedisquotaSpecFluent.QuotasNested<A> addNewQuotaLike(me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public RedisquotaSpecFluent.QuotasNested<A> setNewQuotaLike(int index,me.snowdrop.istio.mixer.adapter.redisquota.Quota item);
    public RedisquotaSpecFluent.QuotasNested<A> editQuota(int index);
    public RedisquotaSpecFluent.QuotasNested<A> editFirstQuota();
    public RedisquotaSpecFluent.QuotasNested<A> editLastQuota();
    public RedisquotaSpecFluent.QuotasNested<A> editMatchingQuota(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.QuotaBuilder> predicate);
    public String getRedisServerUrl();
    public A withRedisServerUrl(String redisServerUrl);
    public Boolean hasRedisServerUrl();
    public A withNewRedisServerUrl(String arg1);
    public A withNewRedisServerUrl(StringBuilder arg1);
    public A withNewRedisServerUrl(StringBuffer arg1);

    public interface QuotasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.redisquota.QuotaFluent<RedisquotaSpecFluent.QuotasNested<N>>{

        
    public N and();    public N endQuota();
}


}
